summaryrefslogtreecommitdiffstats
path: root/src/klamav.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/klamav.h')
-rw-r--r--src/klamav.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/klamav.h b/src/klamav.h
index 80552fa..01a0b07 100644
--- a/src/klamav.h
+++ b/src/klamav.h
@@ -9,14 +9,14 @@
#include <config.h>
#endif
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
#include <tqtabwidget.h>
#include <stdlib.h>
class KPrinter;
-class KToggleAction;
+class TDEToggleAction;
class KURL;
class TQLineEdit;
class TQComboBox;
@@ -24,8 +24,8 @@ class TQCheckBox;
class TQListBox;
class TQPushButton;
class TQLabel;
-class KProcess;
-class KConfig;
+class TDEProcess;
+class TDEConfig;
class KURLRequester;
class Freshklam;
class Sigtool;
@@ -46,7 +46,7 @@ class KSystemTray;
* @author $AUTHOR <$EMAIL>
* @version $APP_VERSION
*/
-class Klamav : public KMainWindow
+class Klamav : public TDEMainWindow
{
Q_OBJECT
public:
@@ -67,10 +67,10 @@ public:
KlamavDock *m_dock;
KSystemTray *_tray;
- KAction *EnableKlamd;
- KAction *DisableKlamd;
- KAction *EnableFreshklam;
- KAction *DisableFreshklam;
+ TDEAction *EnableKlamd;
+ TDEAction *DisableKlamd;
+ TDEAction *EnableFreshklam;
+ TDEAction *DisableFreshklam;
Klamd *klamd;
Freshklam *freshklam;
bool firstDownload;
@@ -99,14 +99,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- //void saveProperties(KConfig *);
+ //void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- //void readProperties(KConfig *);
+ //void readProperties(TDEConfig *);
public slots:
void contextDisable();
@@ -148,9 +148,9 @@ private:
TQListBox *resultbox;
TQPushButton *search_button, *cancel_button;
TQLabel *status_label, *matches_label;
- KProcess *childproc;
+ TDEProcess *childproc;
TQString buf;
- KConfig* config;
+ TDEConfig* config;
TQStringList lastSearchItems;
TQStringList lastSearchPaths;
Sigtool *sigtool;
@@ -158,6 +158,6 @@ private:
};
-extern Klamav *kmain;
+extern Klamav *tdemain;
#endif // _KLAMAV_H_
@@ -99,14 +99,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties